@@ -2,23 +2,29 @@
 from abc import ABCMeta
 from abc import abstractmethod
 from argparse import ArgumentParser
+from typing import Any
 from typing import Iterable
 from typing import List
 from typing import Optional
-
-import zope.interface
+from typing import Type
+from typing import TYPE_CHECKING
+from typing import Union
 
 from acme.challenges import Challenge
 from acme.challenges import ChallengeResponse
-from certbot.achallenges import AnnotatedChallenge
+from acme.client import ClientV2
 from certbot import configuration
+from certbot.achallenges import AnnotatedChallenge
+
+if TYPE_CHECKING:
+    from certbot._internal.account import Account
 
 
 class AccountStorage(metaclass=ABCMeta):
     """Accounts storage interface."""
 
     @abstractmethod
-    def find_all(self):  # pragma: no cover
+    def find_all(self) -> List['Account']:  # pragma: no cover
         """Find all accounts.
 
         :returns: All found accounts.
@@ -28,17 +34,20 @@ class AccountStorage(metaclass=ABCMeta):
         raise NotImplementedError()
 
     @abstractmethod
-    def load(self, account_id):  # pragma: no cover
+    def load(self, account_id: str) -> 'Account':  # pragma: no cover
         """Load an account by its id.
 
         :raises .AccountNotFound: if account could not be found
         :raises .AccountStorageError: if account could not be loaded
 
+        :returns: The account loaded
+        :rtype: .Account
+
         """
         raise NotImplementedError()
 
     @abstractmethod
-    def save(self, account, client):  # pragma: no cover
+    def save(self, account: 'Account', client: ClientV2) -> None:  # pragma: no cover
         """Save account.
 
         :raises .AccountStorageError: if account could not be saved
@@ -47,18 +56,6 @@ class AccountStorage(metaclass=ABCMeta):
         raise NotImplementedError()
 
 
-class IConfig(zope.interface.Interface):  # pylint: disable=inherit-non-class
-    """Deprecated, use certbot.configuration.NamespaceConfig instead."""
-
-
-class IPluginFactory(zope.interface.Interface):  # pylint: disable=inherit-non-class
-    """Deprecated, use certbot.interfaces.Plugin as ABC instead."""
-
-
-class IPlugin(zope.interface.Interface):  # pylint: disable=inherit-non-class
-    """Deprecated, use certbot.interfaces.Plugin as ABC instead."""
-
-
 class Plugin(metaclass=ABCMeta):
     """Certbot plugin.
 
@@ -92,8 +89,11 @@ class Plugin(metaclass=ABCMeta):
     description: str = NotImplemented
     """Short plugin description"""
 
+    name: str = NotImplemented
+    """Unique name of the plugin"""
+
     @abstractmethod
-    def __init__(self, config: configuration.NamespaceConfig, name: str):
+    def __init__(self, config: Optional[configuration.NamespaceConfig], name: str) -> None:
         """Create a new `Plugin`.
 
         :param configuration.NamespaceConfig config: Configuration.
@@ -150,10 +150,6 @@ class Plugin(metaclass=ABCMeta):
         """
 
 
-class IAuthenticator(IPlugin):  # pylint: disable=inherit-non-class
-    """Deprecated, use certbot.interfaces.Authenticator as ABC instead."""
-
-
 class Authenticator(Plugin):
     """Generic Certbot Authenticator.
 
@@ -163,7 +159,7 @@ class Authenticator(Plugin):
     """
 
     @abstractmethod
-    def get_chall_pref(self, domain: str) -> Iterable[Challenge]:
+    def get_chall_pref(self, domain: str) -> Iterable[Type[Challenge]]:
         """Return `collections.Iterable` of challenge preferences.
 
         :param str domain: Domain for which challenge preferences are sought.
@@ -177,7 +173,7 @@ class Authenticator(Plugin):
         """
 
     @abstractmethod
-    def perform(self, achalls: List[AnnotatedChallenge]) -> Iterable[ChallengeResponse]:
+    def perform(self, achalls: List[AnnotatedChallenge]) -> List[ChallengeResponse]:
         """Perform the given challenge.
 
         :param list achalls: Non-empty (guaranteed) list of
@@ -185,10 +181,10 @@ class Authenticator(Plugin):
             instances, such that it contains types found within
             :func:`get_chall_pref` only.
 
-        :returns: `collections.Iterable` of ACME
+        :returns: list of ACME
             :class:`~acme.challenges.ChallengeResponse` instances corresponding to each provided
             :class:`~acme.challenges.Challenge`.
-        :rtype: :class:`collections.Iterable` of
+        :rtype: :class:`collections.List` of
             :class:`acme.challenges.ChallengeResponse`,
             where responses are required to be returned in
             the same order as corresponding input challenges
@@ -213,10 +209,6 @@ class Authenticator(Plugin):
         """
 
 
-class IInstaller(IPlugin):  # pylint: disable=inherit-non-class
-    """Deprecated, use certbot.interfaces.Installer as ABC instead."""
-
-
 class Installer(Plugin):
     """Generic Certbot Installer Interface.
 
@@ -257,7 +249,8 @@ class Installer(Plugin):
         """
 
     @abstractmethod
-    def enhance(self, domain: str, enhancement: str, options: Optional[List[str]] = None) -> None:
+    def enhance(self, domain: str, enhancement: str,
+                options: Optional[Union[List[str], str]] = None) -> None:
         """Perform a configuration enhancement.
 
         :param str domain: domain for which to provide enhancement
@@ -343,20 +336,12 @@ class Installer(Plugin):
         """
 
 
-class IDisplay(zope.interface.Interface):  # pylint: disable=inherit-non-class
-    """Deprecated, use your own Display implementation instead."""
-
-
-class IReporter(zope.interface.Interface):  # pylint: disable=inherit-non-class
-    """Deprecated, use your own Reporter implementation instead."""
-
-
 class RenewableCert(metaclass=ABCMeta):
     """Interface to a certificate lineage."""
 
     @property
     @abstractmethod
-    def cert_path(self):
+    def cert_path(self) -> str:
         """Path to the certificate file.
 
         :rtype: str
@@ -365,7 +350,7 @@ class RenewableCert(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def key_path(self):
+    def key_path(self) -> str:
         """Path to the private key file.
 
         :rtype: str
@@ -374,7 +359,7 @@ class RenewableCert(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def chain_path(self):
+    def chain_path(self) -> str:
         """Path to the certificate chain file.
 
         :rtype: str
@@ -383,7 +368,7 @@ class RenewableCert(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def fullchain_path(self):
+    def fullchain_path(self) -> str:
         """Path to the full chain file.
 
         The full chain is the certificate file plus the chain file.
@@ -394,7 +379,7 @@ class RenewableCert(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def lineagename(self):
+    def lineagename(self) -> str:
         """Name given to the certificate lineage.
 
         :rtype: str
@@ -402,7 +387,7 @@ class RenewableCert(metaclass=ABCMeta):
         """
 
     @abstractmethod
-    def names(self):
+    def names(self) -> List[str]:
         """What are the subject names of this certificate?
 
         :returns: the subject names
@@ -434,11 +419,11 @@ class GenericUpdater(metaclass=ABCMeta):
 
     The plugins implementing this enhancement are responsible of handling
     the saving of configuration checkpoints as well as other calls to
-    interface methods of `interfaces.IInstaller` such as prepare() and restart()
+    interface methods of `interfaces.Installer` such as prepare() and restart()
     """
 
     @abstractmethod
-    def generic_updates(self, lineage, *args, **kwargs):
+    def generic_updates(self, lineage: RenewableCert, *args: Any, **kwargs: Any) -> None:
         """Perform any update types defined by the installer.
 
         If an installer is a subclass of the class containing this method, this
@@ -466,11 +451,11 @@ class RenewDeployer(metaclass=ABCMeta):
     """
 
     @abstractmethod
-    def renew_deploy(self, lineage, *args, **kwargs):
+    def renew_deploy(self, lineage: RenewableCert, *args: Any, **kwargs: Any) -> None:
         """Perform updates defined by installer when a certificate has been renewed
 
         If an installer is a subclass of the class containing this method, this
-        function will always be called when a certficate has been renewed by
+        function will always be called when a certificate has been renewed by
         running "certbot renew". For example if a plugin needs to copy a
         certificate over, or change configuration based on the new certificate.
 
